@@ -12,6 +12,8 @@ use String::Unquotemeta;
 use JSON::Syck;
 use JavaScript::Minifier::XS;
 
+#### this ugliness will be spruced up when we go to CLDR-via-JSON in rt 69340 (no XML voo doo and we can move to TT for mod building) ##
+
 # datetime.json
 our $tripped;
 use Test::Carp sub { $tripped = 1 if $_[0]; };
@@ -78,7 +80,7 @@ $Data::Dumper::Useqq    = 1;
     }
 }
 
-my $v_offset     = '0.17';
+my $v_offset     = '0.22';
 my $mod_version  = $Locales::VERSION - $v_offset;
 my $cldr_version = $Locales::cldr_version;
 my $cldr_db_path;
@@ -154,7 +156,9 @@ sub get_target_structs_from_cldr_for_tag {
 
     #### Territories ####
     for my $trr ( keys %{ $raw_struct->{'localeDisplayNames'}{'territories'}{'territory'} } ) {
-        next if $trr =~ m/^\d+$/;
+
+        # Do not skip ISO 3166-1-numeric (e.g. 419, as in es_419)
+        # next if $trr =~ m/^\d+$/;
 
         my $short = $trr;
         $short =~ tr/A-Z/a-z/;
@@ -243,12 +247,12 @@ sub get_target_structs_from_cldr_for_tag {
       ? (
           ref $raw_struct->{'numbers'}{'symbols'}[$symbols_index]{'group'} eq 'HASH'  ? $raw_struct->{'numbers'}{'symbols'}[$symbols_index]{'group'}{'content'}
         : ref $raw_struct->{'numbers'}{'symbols'}[$symbols_index]{'group'} eq 'ARRAY' ? $raw_struct->{'numbers'}{'symbols'}[$symbols_index]{'group'}->[0]
-        : $raw_struct->{'numbers'}{'symbols'}[$symbols_index]{'group'}
+        :                                                                               $raw_struct->{'numbers'}{'symbols'}[$symbols_index]{'group'}
       )
       : (
           ref $raw_struct->{'numbers'}{'symbols'}{'group'} eq 'HASH'  ? $raw_struct->{'numbers'}{'symbols'}{'group'}{'content'}
         : ref $raw_struct->{'numbers'}{'symbols'}{'group'} eq 'ARRAY' ? $raw_struct->{'numbers'}{'symbols'}{'group'}->[0]
-        : $raw_struct->{'numbers'}{'symbols'}{'group'}
+        :                                                               $raw_struct->{'numbers'}{'symbols'}{'group'}
       );
     if ( ref($_decimal_format_group) eq 'HASH' ) {
         $_decimal_format_group = $_decimal_format_group->{'content'};
@@ -264,7 +268,7 @@ sub get_target_structs_from_cldr_for_tag {
       : (
           ref $raw_struct->{'numbers'}{'symbols'}{'decimal'} eq 'HASH'  ? $raw_struct->{'numbers'}{'symbols'}{'decimal'}{'content'}
         : ref $raw_struct->{'numbers'}{'symbols'}{'decimal'} eq 'ARRAY' ? $raw_struct->{'numbers'}{'symbols'}{'decimal'}->[0]
-        : $raw_struct->{'numbers'}{'symbols'}{'decimal'}
+        :                                                                 $raw_struct->{'numbers'}{'symbols'}{'decimal'}
       );
     if ( ref($_decimal_format_decimal) eq 'HASH' ) {
         $_decimal_format_decimal = $_decimal_format_decimal->{'content'};
@@ -320,12 +324,12 @@ sub get_target_structs_from_cldr_for_tag {
         ? (
               ref $raw_struct->{'numbers'}{'symbols'}[$symbols_index]{'percentSign'} eq 'HASH'  ? $raw_struct->{'numbers'}{'symbols'}[$symbols_index]{'percentSign'}{'content'}
             : ref $raw_struct->{'numbers'}{'symbols'}[$symbols_index]{'percentSign'} eq 'ARRAY' ? $raw_struct->{'numbers'}{'symbols'}[$symbols_index]{'percentSign'}->[0]
-            : $raw_struct->{'numbers'}{'symbols'}[$symbols_index]{'percentSign'}
+            :                                                                                     $raw_struct->{'numbers'}{'symbols'}[$symbols_index]{'percentSign'}
           )
         : (
               ref $raw_struct->{'numbers'}{'symbols'}{'percentSign'} eq 'HASH'  ? $raw_struct->{'numbers'}{'symbols'}{'percentSign'}{'content'}
             : ref $raw_struct->{'numbers'}{'symbols'}{'percentSign'} eq 'ARRAY' ? $raw_struct->{'numbers'}{'symbols'}{'percentSign'}->[0]
-            : $raw_struct->{'numbers'}{'symbols'}{'percentSign'}
+            :                                                                     $raw_struct->{'numbers'}{'symbols'}{'percentSign'}
         )
       )
       || $fallback_lang_misc_info->{'cldr_formats'}{'_percent_format_percent'};
@@ -394,7 +398,7 @@ sub get_target_structs_from_cldr_for_tag {
                 : (
                       ref $raw_struct->{'numbers'}{'decimalFormats'}{'decimalFormatLength'}{'decimalFormat'}{'pattern'} eq 'HASH'  ? $raw_struct->{'numbers'}{'decimalFormats'}{'decimalFormatLength'}{'decimalFormat'}{'pattern'}{'content'}
                     : ref $raw_struct->{'numbers'}{'decimalFormats'}{'decimalFormatLength'}{'decimalFormat'}{'pattern'} eq 'ARRAY' ? $raw_struct->{'numbers'}{'decimalFormats'}{'decimalFormatLength'}{'decimalFormat'}{'pattern'}->[0]
-                    : $raw_struct->{'numbers'}{'decimalFormats'}{'decimalFormatLength'}{'decimalFormat'}{'pattern'}
+                    :                                                                                                                $raw_struct->{'numbers'}{'decimalFormats'}{'decimalFormatLength'}{'decimalFormat'}{'pattern'}
                 )
               )
               || Encode::decode_utf8( $fallback_lang_misc_info->{'cldr_formats'}{'decimal'} ),
@@ -403,7 +407,7 @@ sub get_target_structs_from_cldr_for_tag {
             'percent'                 => (
                   ref $raw_struct->{'numbers'}{'percentFormats'}{'percentFormatLength'}{'percentFormat'}{'pattern'} eq 'HASH'  ? $raw_struct->{'numbers'}{'percentFormats'}{'percentFormatLength'}{'percentFormat'}{'pattern'}{'content'}
                 : ref $raw_struct->{'numbers'}{'percentFormats'}{'percentFormatLength'}{'percentFormat'}{'pattern'} eq 'ARRAY' ? $raw_struct->{'numbers'}{'percentFormats'}{'percentFormatLength'}{'percentFormat'}{'pattern'}->[0]
-                : $raw_struct->{'numbers'}{'percentFormats'}{'percentFormatLength'}{'percentFormat'}{'pattern'}
+                :                                                                                                                $raw_struct->{'numbers'}{'percentFormats'}{'percentFormatLength'}{'percentFormat'}{'pattern'}
               )
               || Encode::decode_utf8( $fallback_lang_misc_info->{'cldr_formats'}{'percent'} ),
             '_percent_format_percent' => $_percent_format_percent,
@@ -429,7 +433,11 @@ sub get_target_structs_from_cldr_for_tag {
             },
         },
         'characters' => {
-            'more_information' => $raw_struct->{'characters'}{'moreInformation'} || Encode::decode_utf8( $fallback_lang_misc_info->{'characters'}{'more_information'} ),
+            'more_information' => (
+                ref( $raw_struct->{'characters'}{'moreInformation'} ) eq 'HASH'
+                ? ( $raw_struct->{'characters'}{'moreInformation'}{'content'} || Encode::decode_utf8( $fallback_lang_misc_info->{'characters'}{'more_information'} ) )
+                : ( $raw_struct->{'characters'}{'moreInformation'} || Encode::decode_utf8( $fallback_lang_misc_info->{'characters'}{'more_information'} ) )
+            )
         },
         'delimiters' => {
             map {
@@ -452,7 +460,7 @@ sub get_target_structs_from_cldr_for_tag {
                         : $fallback_lang_misc_info->{'delimiters'}{$norm}
                     )
                   )
-              } ( 'quotationStart', 'quotationEnd', 'alternateQuotationStart', 'alternateQuotationEnd' )
+            } ( 'quotationStart', 'quotationEnd', 'alternateQuotationStart', 'alternateQuotationEnd' )
         },
         'plural_forms' => {
 
@@ -548,6 +556,9 @@ sub write_language_module {
     _write_utf8_perl(
         "Language/$tag.pm", qq{package Locales::DB::Language::$tag;
 
+use strict;
+use warnings;
+
 # Auto generated from CLDR
 
 \$Locales::DB::Language::$tag\::VERSION = '$mod_version';
@@ -580,6 +591,9 @@ sub write_territory_module {
     _write_utf8_perl(
         "Territory/$tag.pm", qq{package Locales::DB::Territory::$tag;
 
+use strict;
+use warnings;
+
 # Auto generated from CLDR
 
 \$Locales::DB::Territory::$tag\::VERSION = '$mod_version';
@@ -714,12 +728,12 @@ sub write_get_plural_form_test {
     my ($tag) = @_;
 
     my $loc = Locales->new($tag) || die die "Could not create object for $tag: \$@";
-    
+
     my $arg_tests_count = 2;
     if ( $loc->get_plural_form(0) eq 'other' ) {
         $arg_tests_count = 4;
     }
-    
+
     _write_utf8_perl(
         "../../../t/06.$tag.t", qq{
 # Auto generated during CLDR build
@@ -809,6 +823,9 @@ sub write_native_module {
     _write_utf8_perl(
         "$locales_db/Native.pm", qq{package Locales::DB::Native;
 
+use strict;
+use warnings;
+
 # Auto generated from CLDR
 
 \$Locales::DB::Native::VERSION = '$mod_version';
@@ -828,6 +845,53 @@ $fallback_lookup_str);
     );
 }
 
+sub write_db_loadable_module {
+    my $en = Locales->new('en');
+
+    my $code_hr;
+    my $terr_hr;
+
+    for my $t ( $en->get_territory_codes() ) {
+        $terr_hr->{$t} = 1;
+    }
+
+    for my $c ( $en->get_language_codes() ) {
+        next if Locales::is_non_locale($c);
+
+        if ( Locales->new($c) ) {
+            $code_hr->{$c} = 1;
+        }
+    }
+
+    my $code_str = _stringify_hash_no_dumper($code_hr);
+    my $terr_str = _stringify_hash_no_dumper($terr_hr);
+
+    _write_utf8_perl(
+        "$locales_db/Loadable.pm", qq{package Locales::DB::Loadable;
+
+use strict;
+use warnings;
+
+# Auto generated from CLDR
+
+\$Locales::DB::Loadable::VERSION = '$mod_version';
+
+\$Locales::DB::Loadable::cldr_version = '$cldr_version';
+
+\%Locales::DB::Loadable::code = ( 
+$code_str);
+
+\%Locales::DB::Loadable::territory = (
+$terr_str);
+
+1;    
+        },
+        'lib/Locales/DB/Loadable.pm',
+        1,
+    );
+
+}
+
 sub write_character_orientation_module {
     my ( $text_direction_map, $fallback_lookup ) = @_;
 
@@ -837,6 +901,9 @@ sub write_character_orientation_module {
     _write_utf8_perl(
         "$locales_db/CharacterOrientation.pm", qq{package Locales::DB::CharacterOrientation;
 
+use strict;
+use warnings;
+
 # Auto generated from CLDR
 
 \$Locales::DB::CharacterOrientation::VERSION = '$mod_version';
@@ -871,6 +938,9 @@ $fallback_lookup_str);
     _write_utf8_perl(
         "$locales_db/CharacterOrientation/Tiny.pm", qq{package Locales::DB::CharacterOrientation::Tiny;
 
+use strict;
+use warnings;
+
 # Auto generated from CLDR
 
 \$Locales::DB::CharacterOrientation::Tiny::VERSION = '$mod_version';
@@ -910,6 +980,9 @@ sub write_name_pattern_module {
     _write_utf8_perl(
         "$locales_db/LocaleDisplayPattern.pm", qq{package Locales::DB::LocaleDisplayPattern;
 
+use strict;
+use warnings;
+
 # Auto generated from CLDR
 
 \$Locales::DB::LocaleDisplayPattern::VERSION = '$mod_version';
@@ -949,6 +1022,9 @@ $fallback_lookup_str);
     _write_utf8_perl(
         "$locales_db/LocaleDisplayPattern/Tiny.pm", qq{package Locales::DB::LocaleDisplayPattern::Tiny;
 
+use strict;
+use warnings;
+
 # Auto generated from CLDR
 
 \$Locales::DB::LocaleDisplayPattern::Tiny::VERSION = '$mod_version';
@@ -983,7 +1059,10 @@ sub write_plural_forms_argument_pod {
     my ( $plural_forms, $isfallback ) = @_;
     File::Path::Tiny::mk("$locales_db/Docs") || die "Could not create '$locales_db/Docs': $!";
 
-    my $pod_items = '';
+    my $pod_starts = '__END__';                           # this is to help prevent mis-parsing for CPAN like rt 76129 (probably not necessary)
+    my $pkg        = 'Locales::DB::Docs::PluralForms';    # this is to help prevent mis-parsing for CPAN like rt 76129
+    my $pod_mark   = '=';                                 # this is to help prevent mis-parsing for CPAN like rt 80546 (and not fixed *again* in 0.28)
+    my $pod_items  = '';
 
     for my $ent ( @{$plural_forms} ) {
 
@@ -1003,7 +1082,10 @@ sub write_plural_forms_argument_pod {
 
     # $locales_db/Docs/PluralForms.pm
     _write_utf8_perl(
-        "$locales_db/Docs/PluralForms.pm", qq{package Locales::DB::Docs::PluralForms;
+        "$locales_db/Docs/PluralForms.pm", qq{package $pkg;
+
+use strict;
+use warnings;
 
 # Auto generated from CLDR
 
@@ -1013,20 +1095,20 @@ sub write_plural_forms_argument_pod {
 
 1;
 
-__END__
+$pod_starts
 
-=encoding utf-8
+${pod_mark}encoding utf-8
 
-=head1 NAME
+${pod_mark}head1 NAME
 
 Locales::DB::Docs::PluralForms - plural form details reference for all
 included locales
 
-=head1 VERSION
+${pod_mark}head1 VERSION
 
 Locales.pm v$mod_version (based on CLDR v$cldr_version)
 
-=head1 DESCRIPTION
+${pod_mark}head1 DESCRIPTION
 
 CLDR L<defines a set of broad plural categories and rules|http://unicode.org/repos/cldr-tmp/trunk/diff/supplemental/language_plural_rules.html> that determine which category any given number will fall under.
 
@@ -1034,42 +1116,40 @@ L<Locales> allows you to determine the plural categories applicable to a specifi
 
 This POD documents which categories and in what order you'd specify them in additional arguments to L<Locales/get_plural_form()> (i.e. the optional arguments after the number).
 
-=head2 “Special Zero” Argument
+${pod_mark}head2 “Special Zero” Argument
 
 In addition to the CLDR category value list you can also specify one additional argument of what to use for zero instead of the value for “other”.
 
 This won't be used if 0 falls under a specific category besides “other”.
 
-=head1 
+${pod_mark}head1 Plural Category Argument Order Reference
 
-=head1 Plural Category Argument Order Reference
-
-=over 4
+${pod_mark}over 4
 
 $pod_items
 
-=back
+${pod_mark}back
 
-=head1 BUGS AND LIMITATIONS
+${pod_mark}head1 BUGS AND LIMITATIONS
 
 Please see L<Locales/BUGS AND LIMITATIONS>
 
-=head2 BEFORE YOU SUBMIT A BUG REPORT
+${pod_mark}head2 BEFORE YOU SUBMIT A BUG REPORT
 
 Please see L<Locales/BEFORE YOU SUBMIT A BUG REPORT>
 
-=head1 AUTHOR
+${pod_mark}head1 AUTHOR
 
 Daniel Muey  C<< <http://drmuey.com/cpan_contact.pl> >>
 
-=head1 LICENCE AND COPYRIGHT
+${pod_mark}head1 LICENCE AND COPYRIGHT
 
 Copyright (c) 2009, Daniel Muey C<< <http://drmuey.com/cpan_contact.pl> >>. All rights reserved.
 
 This module is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself. See L<perlartistic>.
 
-=head1 DISCLAIMER OF WARRANTY
+${pod_mark}head1 DISCLAIMER OF WARRANTY
 
 BECAUSE THIS SOFTWARE IS LICENSED FREE OF CHARGE, THERE IS NO WARRANTY
 FOR THE SOFTWARE, TO THE EXTENT PERMITTED BY APPLICABLE LAW. EXCEPT WHEN
@@ -1101,6 +1181,13 @@ SUCH DAMAGES.
 sub build_javascript_share {
     my ($tag) = @_;
 
+    if ( -d 'share/' ) {
+        File::Path::Tiny::rm('share/') || die "Could not remove 'share/': $!";
+    }
+    for my $d (qw(misc_info/ functions/ code_to_name/ datetime/ db/)) {
+        File::Path::Tiny::mk("share/$d") || die "Could not create 'share/$d': $!";
+    }
+
     my $loc = Locales->new();
     for my $tag ( sort $loc->get_language_codes() ) {
         my $tag_loc = Locales->new($tag) || next;
@@ -1121,7 +1208,7 @@ sub build_javascript_share {
         my $cats_proc_js = JSON::Syck::Dump( [ Locales::get_cldr_plural_category_list(1) ] );
         my $cats_rule_js = JSON::Syck::Dump( $guts_m->{'plural_forms'}{'category_rules_compiled'} );
         $cats_rule_js =~ s/"(function[^"]+)"/$1/g;
-        
+
         open( my $fh_f, '>', "share/functions/$tag.js" ) or die "Could not open 'share/functions/$tag.js': $!";
 
         # var category_process_order = $cats_proc_js;
@@ -1251,6 +1338,14 @@ END_FUNC
 
         append_file( $manifest, "share/misc_info/$tag.js\nshare/code_to_name/$tag.json\nshare/datetime/$tag.json\nshare/functions/$tag.js\n" );
     }
+
+    require Locales::DB::Loadable;
+    my $json_d = JSON::Syck::Dump( { 'code' => \%Locales::DB::Loadable::code, 'territory' => \%Locales::DB::Loadable::territory } );    # no eval, lets just die
+    open( my $fh_d, '>', "share/db/loadable.json" ) or die "Could not open 'share/db/loadable.json': $!";
+    print {$fh_d} $json_d;
+    close $fh_d;
+
+    append_file( $manifest, "share/db/loadable.json" );
 }
 
 sub build_manifest {
@@ -1298,7 +1393,7 @@ sub _stringify_hash_no_dumper {
         my $qv = $_[0]->{$k};
         $qk =~ s{\'}{\\\'}g;
         $qv =~ s{\'}{\\\'}g;
-        my $ky = $k          ne $qk ? qq{"$qk"} : qq{'$k'};
+        my $ky = $k ne $qk          ? qq{"$qk"} : qq{'$k'};
         my $vl = $_[0]->{$k} ne $qv ? qq{"$qv"} : qq{'$_[0]->{$k}'};
         $string .= "$ky => $vl,\n";
     }
